@@ -1,20 +1,32 @@
+( cd usr/doc/espgs-8.15.4 ; rm -rf doc )
+( cd usr/doc/espgs-8.15.4 ; ln -sf /usr/share/ghostscript/8.15/doc doc )
+( cd usr/doc/espgs-8.15.4 ; rm -rf examples )
+( cd usr/doc/espgs-8.15.4 ; ln -sf /usr/share/ghostscript/8.15/examples examples )
+( cd usr/man/de/man1 ; rm -rf gsbj.1.gz )
+( cd usr/man/de/man1 ; ln -sf gslp.1.gz gsbj.1.gz )
 ( cd usr/man/de/man1 ; rm -rf eps2eps.1.gz )
 ( cd usr/man/de/man1 ; ln -sf ps2ps.1.gz eps2eps.1.gz )
+( cd usr/man/de/man1 ; rm -rf gsdj.1.gz )
+( cd usr/man/de/man1 ; ln -sf gslp.1.gz gsdj.1.gz )
+( cd usr/man/de/man1 ; rm -rf gslj.1.gz )
+( cd usr/man/de/man1 ; ln -sf gslp.1.gz gslj.1.gz )
 ( cd usr/man/de/man1 ; rm -rf ps2pdf12.1.gz )
 ( cd usr/man/de/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
 ( cd usr/man/de/man1 ; rm -rf ps2pdf13.1.gz )
 ( cd usr/man/de/man1 ; ln -sf ps2pdf.1.gz ps2pdf13.1.gz )
-( cd usr/man/man1 ; rm -rf eps2eps.1.gz )
-( cd usr/man/man1 ; ln -sf ps2ps.1.gz eps2eps.1.gz )
+( cd usr/man/de/man1 ; rm -rf gsdj500.1.gz )
+( cd usr/man/de/man1 ; ln -sf gslp.1.gz gsdj500.1.gz )
 ( cd usr/man/man1 ; rm -rf gsbj.1.gz )
 ( cd usr/man/man1 ; ln -sf gslp.1.gz gsbj.1.gz )
+( cd usr/man/man1 ; rm -rf eps2eps.1.gz )
+( cd usr/man/man1 ; ln -sf ps2ps.1.gz eps2eps.1.gz )
 ( cd usr/man/man1 ; rm -rf gsdj.1.gz )
 ( cd usr/man/man1 ; ln -sf gslp.1.gz gsdj.1.gz )
-( cd usr/man/man1 ; rm -rf gsdj500.1.gz )
-( cd usr/man/man1 ; ln -sf gslp.1.gz gsdj500.1.gz )
-( cd usr/man/man1 ; rm -rf ps2pdf12.1.gz )
-( cd usr/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
 ( cd usr/man/man1 ; rm -rf gslj.1.gz )
 ( cd usr/man/man1 ; ln -sf gslp.1.gz gslj.1.gz )
+( cd usr/man/man1 ; rm -rf ps2pdf12.1.gz )
+( cd usr/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
 ( cd usr/man/man1 ; rm -rf ps2pdf13.1.gz )
 ( cd usr/man/man1 ; ln -sf ps2pdf.1.gz ps2pdf13.1.gz )
+( cd usr/man/man1 ; rm -rf gsdj500.1.gz )
+( cd usr/man/man1 ; ln -sf gslp.1.gz gsdj500.1.gz )
